@@ -1,19 +1,21 @@
 package Mojolicious::Che;
 use Mojo::Base::Che 'Mojolicious';
-use Mojo::Loader qw(load_class);
+#~ use Mojo::Loader qw(load_class);
 
-our $VERSION = '0.021';
+our $VERSION = '0.024';
 
 =pod
 
 =head1 VERSION
 
-0.021
+0.024
 
 =cut
 
-sub поехали {
-  my $app = shift;
+sub new {
+  my $app = shift->SUPER::new;
+  my %args = @_;
+  $app->plugin(Config =>{file => $args{config} || 'Config.pm'});
   my $conf = $app->config;
   
   my $defaults = $conf->{'mojo_defaults'} || $conf->{'mojo'}{'defaults'};
@@ -35,6 +37,8 @@ sub поехали {
   $app->хуки();
   $app->спейсы();
   $app->маршруты();
+  
+  return $app;
 
 }
 
@@ -103,10 +107,11 @@ has sth => sub {
   
   my $c_dbh = $conf->{dbh} || $conf->{'базы'};
   my $c_sth = $conf->{sth} || $conf->{'запросы'} || {};
-  my $c_pos = $conf->{pos} || $conf->{'посы'} || {};
+  #~ my $c_pos = $conf->{pos} || $conf->{'посы'} || {};
     
-  return unless ($c_sth && ref($c_sth) eq 'HASH' && keys %$c_sth)
-    || ($c_pos && ref($c_pos) eq 'HASH' && keys %$c_pos);
+  return
+    unless ($c_sth && ref($c_sth) eq 'HASH' && keys %$c_sth);
+    #~ || ($c_pos && ref($c_pos) eq 'HASH' && keys %$c_pos);
 
   my $sth = {};
   
@@ -124,15 +129,15 @@ has sth => sub {
     }
   }
   
-  my $sth_pos;
-  while (my ($db, $arr) = each %$c_pos) {
-    for my $item (@$arr) {
-      $sth_pos ||= $app->_class('DBIx::POS::Sth');
-      my $pos_module = $app->_class(ref $item eq 'ARRAY' ? shift @$item : $item);
-      $sth->{$db}{$pos_module} = $sth_pos->new($dbh->{$db}, $pos_module->new(ref $item eq 'ARRAY' ? @$item : ()));
-      $app->log->debug("Создан STH из POS модуля [$pos_module]");
-    }
-  }
+  #~ my $sth_pos;
+  #~ while (my ($db, $arr) = each %$c_pos) {
+    #~ for my $item (@$arr) {
+      #~ $sth_pos ||= $app->_class('DBIx::POS::Sth');
+      #~ my $pos_module = $app->_class(ref $item eq 'ARRAY' ? shift @$item : $item);
+      #~ $sth->{$db}{$pos_module} = $sth_pos->new($dbh->{$db}, $pos_module->new(ref $item eq 'ARRAY' ? @$item : ()));
+      #~ $app->log->debug("Создан STH из POS модуля [$pos_module]");
+    #~ }
+  #~ }
   
   $sth;
 };
@@ -201,22 +206,22 @@ sub спейсы {
   push @{$app->routes->namespaces}, @$ns;
 }
 
-sub Mojolicious::Routes::is_hidden0000 {
-  my ($self, $method) = @_;
-  my $h = $self->{hiding} ||= {map { $_ => 1 } @{$self->hidden}};
-  #~ return !!($h->{$method} || index($method, '_') == 0 || $method !~ /[a-z]/);
-  #~ return !!($h->{$method} || index($method, '_') == 0);
-   return !!($h->{$method} || $method =~ /^_/ || $method =~ /^[A-Z_]+$/);
-}
+#~ sub Mojolicious::Routes::is_hidden0000 {
+  #~ my ($self, $method) = @_;
+  #~ my $h = $self->{hiding} ||= {map { $_ => 1 } @{$self->hidden}};
+  ##return !!($h->{$method} || index($method, '_') == 0 || $method !~ /[a-z]/);
+  ##return !!($h->{$method} || index($method, '_') == 0);
+   #~ return !!($h->{$method} || $method =~ /^_/ || $method =~ /^[A-Z_]+$/);
+#~ }
 
-sub _class {
-  my $self = shift;
-  my $class  = shift;
-  my $e;
-  $e = load_class($class)# success undef
-    and die $e;
-  return $class;
-}
+#~ sub _class {
+  #~ my $self = shift;
+  #~ my $class  = shift;
+  #~ my $e;
+  #~ $e = load_class($class)# success undef
+    #~ and die $e;
+  #~ return $class;
+#~ }
 
 1;
 
@@ -236,14 +241,9 @@ Mojolicious::Che - Мой базовый модуль для приложени
 
 =head1 SYNOPSIS
 
-  use Mojo::Base::Che 'Mojolicious::Che';
+  use Mojo::Base::Che 'Mojolicious::Che' -lib, 'lib';
   
-  sub startup {
-    my $app = shift;
-    $app->plugin(Config =>{file => 'Config.pm'});
-    $app->поехали();
-  }
-  __PACKAGE__->new()->start();
+  __PACKAGE__->new(config => 'lib/Config.pm')->start();
 
 
 =head1 Config file
@@ -271,9 +271,9 @@ Mojolicious::Che - Мой базовый модуль для приложени
   # 'сессия' => 
   mojo_session => {cookie_name => 'ELK'},
   
-  # 'хазы' => 'Лет 500-700 назад был такой дикий степной торговый жадный народ ХАЗАРЫ. Столицей их "государства" был город Тьмутаракань, где-то на берегу Каспия. Потомки этих людей рассыпаны по странам России, Средней Азии, Европы. Есть мнение, что хазары присвоили себе название ЕВРЕИ, но это не те библейские евреи.'
+  # 'хазы' => 'Лет 500-700 назад был такой дикий степной торговый жадный народ ХАЗАРЫ. Столицей их "государства" был город Тьмутаракань, где-то на берегу моря Каспия. Потомки этих людей рассыпаны по странам России, Средней Азии, Европы. Есть мнение, что хазары присвоили себе название ЕВРЕИ, но это не те библейские кроткие евреи, а жадные потомки кроманьонцев'
   mojo_has => {
-    foo => sub {my $app = shift; return 'bar!';},
+    foo => sub {my $app = shift; return 'is a bar';},
   },
   
   # 'базы' => 
@@ -312,25 +312,18 @@ Mojolicious::Che - Мой базовый модуль для приложени
       now => "select now();"
     },
   },
-  # DBIx::POS::Sth
-  # will be as has $app->sth->{<dbh name>}{<POS module name>}->sth(<statement name>, ...)
-  pos => {
-    main => [# hashref
-      ['POS::Foo' => template => {var1=>1,}],
-    ],
-  },
-    
+  
   # 'плугины'=> [
   mojo_plugins=>[ 
-      [charset => { charset => 'UTF-8' }, ],
-      # or ['FooPlugin' => sub {...returns config hashref...}],
+      ['Foo::Bar'],
+      ['Foo::Plugin' => sub {<...returns config data...>}],
   ],
   # 'хуки' => 
   mojo_hooks=>{
     #~ before_dispatch => sub {1;},
   },
   # 'спейсы' => 
-  namespaces => [],
+  namespaces => ['Space::Shattle'],
   # 'маршруты' => 
   routes => [
     [get=>'/', to=> {cb=>sub{shift->render(format=>'txt', text=>'Hello!');},}],
@@ -347,19 +340,12 @@ Set DBI handlers from config B<dbh> (или B<базы>)
 
 Set prepared stattements from config B<sth> (или B<запросы>).
 
-Также есть опция конфига B<pos>, которая подгружает специальные POS-модули в app->sth. Пример:
-
-  pos => {main => [['POS::Foo' => template => {var1=>1,}],],},
-  pos => {main => {'POS::Foo' => template => {var1=>1,},},},
-  # далее получение запросов
-  my $sth = $app->sth->{main}{'POS::Foo'}->sth('foo st', ...);
-
 =head1 METHODS
 
 Mojolicious::Che inherits all methods from Mojolicious and implements the following new ones.
 All methods has nothing on input.
 
-=head2 поехали()
+=head2 new()
 
 Top-level method. Setup the B<defaults>, B<secrets>, B<mode>, B<log level> from app->config(). Then invoke all other metods in order below.
 
